#!/bin/sh
# @(#) $Id: captive.sh 39 2010-10-15 23:23:27Z leres $ (LBL)

#
# PROVIDE: captive
# KEYWORD: nojail shutdown
# REQUIRE: LOGIN
#

#
# To configure, add variables to /etc/rc.conf:
#
#	captive_enable="YES"
#	captive_users		# optional captive accounts (default: captive)
#	captive*_dev		# dev dir in jail (default: ~user/dev)
#	captive*_devrw="bpf* cuad0" # list of dev's to unhide (default: "")
#

. /etc/rc.subr

name="captive"
rcvar=`set_rcvar`
start_cmd="${name}_start"
stop_cmd="${name}_stop"

load_rc_config $name
users="${captive_users:-${name}}"

captive_start() {
	for user in ${users}; do
		echo "Starting ${name}: ${user}."
		eval dev=\${${user}_dev:-~${user}/dev}
		if [ ! -d "${dev}" ]; then
			echo "Can't find ${dev}" 1>&2
			continue
		fi
		eval devrw=\${${user}_devrw}

		umount ${dev} 2>/dev/null

		devfs_rulesets_from_file /etc/defaults/devfs.rules

		devfs_domount ${dev} devfsrules_hide_all
		devfs -m ${dev} rule apply path null unhide
		devfs -m ${dev} rule apply path random unhide

		# Optionally unhide additional devices
		for d in ${devrw}; do
			devfs -m ${dev} rule apply path "${d}" unhide
			devfs -m ${dev} rule apply path "${d}" mode 666
		done
	done
}

captive_stop() {
	for user in ${users}; do
		echo "Stopping ${name}: ${user}."
		eval dev=\${${user}_dev:-~${user}/dev}
		umount ${dev}
	done
}

run_rc_command "$1"
